Pseudonymisation Tool
=====================

.. automodule:: pymedphys.cli.experimental.dicom
    :no-members:

.. argparse::
   :ref: pymedphys.cli.define_parser
   :prog: pymedphys
   :path: experimental dicom anonymise
